@@ -12,7 +12,7 @@ use nu_source::{
 use num_traits::cast::ToPrimitive;
 
 #[cfg(feature = "dataframe")]
-use nu_protocol::dataframe::{NuSeries, PolarsData};
+use nu_protocol::dataframe::NuDataFrame;
 
 pub trait ValueExt {
     fn into_parts(self) -> (UntaggedValue, Tag);
@@ -203,22 +203,28 @@ pub fn get_data_by_member(value: &Value, name: &PathMember) -> Result<Value, She
             }
         }
         #[cfg(feature = "dataframe")]
-        UntaggedValue::DataFrame(PolarsData::EagerDataFrame(df)) => match &name.unspanned {
+        UntaggedValue::DataFrame(df) => match &name.unspanned {
             UnspannedPathMember::String(string) => {
-                let column = df.as_ref().column(string.as_ref()).map_err(|e| {
-                    ShellError::labeled_error("Dataframe error", format!("{}", e), &name.span)
+                let column = df.as_ref().select(string.as_str()).map_err(|e| {
+                    ShellError::labeled_error("Dataframe error", e.to_string(), &name.span)
                 })?;
 
-                Ok(NuSeries::series_to_value(
-                    column.clone(),
+                Ok(NuDataFrame::dataframe_to_value(
+                    column,
                     Tag::new(value.anchor(), name.span),
                 ))
             }
-            _ => Err(ShellError::labeled_error(
-                "Integer as column",
-                "Only string as column name",
-                &name.span,
-            )),
+            UnspannedPathMember::Int(int) => {
+                if df.is_series() {
+                    df.get_value(*int as usize, name.span)
+                } else {
+                    Err(ShellError::labeled_error(
+                        "Column not found",
+                        "Column name not found in the dataframe",
+                        name.span,
+                    ))
+                }
+            }
         },
         other => Err(ShellError::type_error(
             "row or table",
@@ -237,7 +243,7 @@ where
 {
     let mut current = value.clone();
 
-    for p in path.iter() {
+    for p in path {
         let value = get_data_by_member(&current, p);
 
         match value {
@@ -520,7 +526,7 @@ pub fn forgiving_insert_data_at_column_path(
 
         let mut candidate = new_value;
 
-        for member in paths.iter() {
+        for member in &paths {
             match &member.unspanned {
                 UnspannedPathMember::String(column_name) => {
                     candidate =
@@ -687,16 +693,16 @@ pub fn as_string(value: &Value) -> Result<String, ShellError> {
     match &value.value {
         UntaggedValue::Primitive(Primitive::String(s)) => Ok(s.clone()),
         UntaggedValue::Primitive(Primitive::Date(dt)) => Ok(dt.format("%Y-%m-%d").to_string()),
-        UntaggedValue::Primitive(Primitive::Boolean(x)) => Ok(format!("{}", x)),
-        UntaggedValue::Primitive(Primitive::Decimal(x)) => Ok(format!("{}", x)),
-        UntaggedValue::Primitive(Primitive::Int(x)) => Ok(format!("{}", x)),
-        UntaggedValue::Primitive(Primitive::Filesize(x)) => Ok(format!("{}", x)),
-        UntaggedValue::Primitive(Primitive::FilePath(x)) => Ok(format!("{}", x.display())),
+        UntaggedValue::Primitive(Primitive::Boolean(x)) => Ok(x.to_string()),
+        UntaggedValue::Primitive(Primitive::Decimal(x)) => Ok(x.to_string()),
+        UntaggedValue::Primitive(Primitive::Int(x)) => Ok(x.to_string()),
+        UntaggedValue::Primitive(Primitive::Filesize(x)) => Ok(x.to_string()),
+        UntaggedValue::Primitive(Primitive::FilePath(x)) => Ok(x.display().to_string()),
         UntaggedValue::Primitive(Primitive::ColumnPath(path)) => Ok(path
             .iter()
             .map(|member| match &member.unspanned {
                 UnspannedPathMember::String(name) => name.to_string(),
-                UnspannedPathMember::Int(n) => format!("{}", n),
+                UnspannedPathMember::Int(n) => n.to_string(),
             })
             .join(".")),
 
@@ -746,7 +752,7 @@ pub fn get_data<'value>(value: &'value Value, desc: &str) -> MaybeOwned<'value,
             MaybeOwned::Owned(UntaggedValue::nothing().into_untagged_value())
         }
         #[cfg(feature = "dataframe")]
-        UntaggedValue::DataFrame(_) => {
+        UntaggedValue::DataFrame(_) | UntaggedValue::FrameStruct(_) => {
             MaybeOwned::Owned(UntaggedValue::nothing().into_untagged_value())
         }
     }
